@@ -6,9 +6,7 @@ use strict;
 use Carp;
 use English qw(-no_match_vars);
 
-our $VERSION = '1.04_01';
-
-=for stopwords fallback
+our $VERSION = '1.03';
 
 =head1 NAME
 
@@ -36,11 +34,10 @@ CAM::PDF::GS.
 
 =over
 
-=item $pkg->new($hashref)
+=item new DATA
 
 Create a new instance, setting all state values to their defaults.
-Stores a reference to C<$hashref> and sets the property
-C<$hashref->{fm}> to C<undef>.
+Stores a reference to DATA and sets the DATA property C<fm =E<gt> undef>.
 
 =cut
 
@@ -102,7 +99,7 @@ sub new
    return $self;
 }
 
-=item $self->clone()
+=item clone
 
 Duplicate the instance.
 
@@ -134,9 +131,9 @@ sub clone
 
 =over
 
-=item $self->applyMatrix($m1, $m2)
+=item applyMatrix M1, M2
 
-Apply C<$m1> to C<$m2>, save in C<$m2>.
+Apply m1 to m2, save in m2
 
 =cut
 
@@ -169,10 +166,9 @@ sub applyMatrix
    $m3[5] = $m2->[1]*$m1->[4] + $m2->[3]*$m1->[5] + $m2->[5];
 
    @$m2 = @m3;
-   return;
 }
 
-=item $self->dot($matrix, $x, $y)
+=item dot MATRIX, X, Y
 
 Compute the dot product of a position against the coordinate matrix.
 
@@ -189,7 +185,7 @@ sub dot
            $cm->[1]*$x + $cm->[3]*$y + $cm->[5]);
 }
 
-=item $self->userToDevice($x, $y)
+=item userToDevice X, Y
 
 Convert user coordinates to device coordinates.
 
@@ -207,9 +203,9 @@ sub userToDevice
    return ($x, $y);
 }
 
-=item $self->getCoords($node)
+=item getCoords NODE
 
-Computes device coordinates for the specified node.  This implementation
+Computes device coords for the specified node.  This implementation
 handles line-drawing nodes.
 
 =cut
@@ -220,7 +216,7 @@ sub getCoords
    my $node = shift;
 
    my ($x1,$y1,$x2,$y2);
-   if ($node->{name} =~ m/ \A (?:m|l|h|c|v|y|re) \z /xms)
+   if ($node->{name} =~ /^(?:m|l|h|c|v|y|re)$/)
    {
       ($x1,$y1) = $self->userToDevice(@{$self->{last}});
       ($x2,$y2) = $self->userToDevice(@{$self->{current}});
@@ -228,7 +224,7 @@ sub getCoords
    return ($x1,$y1,$x2,$y2);
 }
 
-=item $self->nodeType($node)
+=item nodeType NODE
 
 Returns one of C<block>, C<path>, C<paint>, C<text> or (the fallback
 case) C<op> for the type of the specified node.
@@ -240,11 +236,11 @@ sub nodeType
    my $self = shift;
    my $node = shift;
 
-   return $node->{type} eq 'block'                                    ? 'block'
-        : $node->{name} =~ / \A (?:m|l|h|c|v|y|re)            \z /xms ? 'path'
-        : $node->{name} =~ / \A (?:S|s|F|f|f\*|B|B\*|b|b\*|n) \z /xms ? 'paint'
-        : $node->{name} =~ / \A T                                /xms ? 'text'
-        :                                                               'op';
+   return $node->{type} eq 'block'                           ? 'block'
+        : $node->{name} =~ /^(?:m|l|h|c|v|y|re)$/            ? 'path'
+        : $node->{name} =~ /^(?:S|s|F|f|f\*|B|B\*|b|b\*|n)$/ ? 'paint'
+        : $node->{name} =~ /^T/                              ? 'text'
+        :                                                      'op';
 }
 
 =back
@@ -253,25 +249,25 @@ sub nodeType
 
 =over
 
-=item $self->i($flatness)
+=item i FLATNESS
 
-=item $self->j($linejoin)
+=item j LINEJOIN
 
-=item $self->J($linecap)
+=item J LINECAP
 
-=item $self->ri($rendering_intent)
+=item ri RENDERING_INTENT
 
-=item $self->Tc($charspace)
+=item Tc CHARSPACE
 
-=item $self->TL($leading)
+=item TL LEADING
 
-=item $self->Tr($rendering_mode)
+=item Tr RENDERING_MODE
 
-=item $self->Ts($rise)
+=item Ts RISE
 
-=item $self->Tw($wordspace)
+=item Tw WORDSPACE
 
-=item $self->w($linewidth)
+=item w LINEWIDTH
 
 =cut
 
@@ -280,11 +276,11 @@ sub nodeType
    no strict 'refs';
    foreach my $name (qw(i j J ri Tc TL Tr Ts Tw w))
    {
-      *{$name} = sub { $_[0]->{$name} = $_[1]; return; };
+      *{$name} = sub { $_[0]->{$name} = $_[1] };
    }
 }
 
-=item $self->g($gray)
+=item g GRAY
 
 =cut
 
@@ -295,10 +291,9 @@ sub g
 
    $self->{g} = [$g];
    $self->{device} = 'DeviceGray';
-   return;
 }
 
-=item $self->G($gray)
+=item G GRAY
 
 =cut
 
@@ -309,10 +304,9 @@ sub G
 
    $self->{G} = [$g];
    $self->{Device} = 'DeviceGray';
-   return;
 }
 
-=item $self->rg($red, $green, $blue)
+=item rg RED GREEN BLUE
 
 =cut
 
@@ -325,10 +319,9 @@ sub rg
 
    $self->{rg} = [$r, $g, $b];
    $self->{device} = 'DeviceRGB';
-   return;
 }
 
-=item $self->RG($red, $green, $blue)
+=item RG RED GREEN BLUE
 
 =cut
 
@@ -341,10 +334,9 @@ sub RG
 
    $self->{RG} = [$r, $g, $b];
    $self->{Device} = 'DeviceRGB';
-   return;
 }
 
-=item $self->k($cyan, $magenta, $yellow, $black)
+=item k CYAN MAGENTA YELLOW BLACK
 
 =cut
 
@@ -358,10 +350,9 @@ sub k
 
    $self->{k} = [$c, $m, $y, $k];
    $self->{device} = 'DeviceCMYK';
-   return;
 }
 
-=item $self->K($cyan, $magenta, $yellow, $black)
+=item K CYAN MAGENTA YELLOW BLACK
 
 =cut
 
@@ -375,12 +366,9 @@ sub K
 
    $self->{K} = [$c, $m, $y, $k];
    $self->{Device} = 'DeviceCMYK';
-   return;
 }
 
-=item $self->gs()
-
-(Not implemented...)
+=item gs (Not implemented...)
 
 =cut
 
@@ -390,10 +378,9 @@ sub gs
 
    # See PDF Ref page 157
    #warn 'gs operator not yet implemented';
-   return;
 }
 
-=item $self->cm M1, M2, M3, M4, M5, M6
+=item cm M1, M2, M3, M4, M5, M6
 
 =cut
 
@@ -402,10 +389,9 @@ sub cm
    my $self = shift;
    
    $self->applyMatrix([@_], $self->{cm});
-   return;
 }
 
-=item $self->d($arrayref, $scalar)
+=item d ARRAYREF, SCALAR
 
 =cut
 
@@ -417,10 +403,9 @@ sub d
 
    @{$self->{da}} = @$da;
    $self->{dp} = $dp;
-   return;
 }
 
-=item $self->m($x, $y)
+=item m X, Y
 
 Move path.
 
@@ -433,10 +418,9 @@ sub m
    my $y = shift;
 
    @{$self->{start}} = @{$self->{last}} = @{$self->{current}} = ($x,$y);
-   return;
 }
 
-=item $self->l($x, $y)
+=item l X, Y
 
 Line path.
 
@@ -450,10 +434,9 @@ sub l
 
    @{$self->{last}} = @{$self->{current}};
    @{$self->{current}} = ($x,$y);
-   return;
 }
 
-=item $self->h()
+=item h
 
 =cut
 
@@ -463,10 +446,9 @@ sub h
 
    @{$self->{last}} = @{$self->{current}};
    @{$self->{current}} = @{$self->{start}};
-   return;
 }
 
-=item $self->c($x1, $y1, $x2, $y2, $x3, $y3)
+=item c X1, Y1, X2, Y2, X3, Y3
 
 =cut
 
@@ -482,10 +464,9 @@ sub c
 
    @{$self->{last}} = @{$self->{current}};
    @{$self->{current}} = ($x3,$y3);
-   return;
 }
 
-=item $self->v($x1, $y1, $x2, $y2)
+=item v X1, Y1, X2, Y2
 
 =cut
 
@@ -499,10 +480,9 @@ sub v
 
    @{$self->{last}} = @{$self->{current}};
    @{$self->{current}} = ($x2,$y2);
-   return;
 }
 
-=item $self->y($x1, $y1, $x2, $y2)
+=item y X1, Y1, X2, Y2
 
 =cut
 
@@ -516,10 +496,9 @@ sub y
 
    @{$self->{last}} = @{$self->{current}};
    @{$self->{current}} = ($x2,$y2);
-   return;
 }
 
-=item $self->re($x, $y, $width, $height)
+=item re X, Y, WIDTH, HEIGHT
 
 Rectangle path.
 
@@ -534,7 +513,6 @@ sub re
    my $h = shift;
 
    @{$self->{start}} = @{$self->{last}} = @{$self->{current}} = ($x,$y);
-   return;
 }
 
 1;
@@ -545,5 +523,3 @@ __END__
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
-
-=cut
