@@ -5,7 +5,7 @@ use warnings;
 use strict;
 use base qw(CAM::PDF::GS);
 
-our $VERSION = '1.04_01';
+our $VERSION = '1.03';
 
 =head1 NAME
 
@@ -32,7 +32,7 @@ example of a renderer.
 
 =over
 
-=item $self->renderText($string)
+=item renderText STRING
 
 Prints the string prefixed by its device and user coordinates.
 
@@ -50,7 +50,6 @@ sub renderText
 
    #my ($dxd, $dyd) = $self->textToDevice(@{$self->{moved}});
    #printf "(%7.2f,%7.2f) -> (%7.2f,%7.2f) %s\n", $xd,$yd,$dxd,$dyd, $string;
-   return;
 }
 
 1;
@@ -61,5 +60,3 @@ __END__
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
-
-=cut
