@@ -4,9 +4,7 @@ use 5.006;
 use warnings;
 use strict;
 
-our $VERSION = '1.04_01';
-
-=for stopwords inline
+our $VERSION = '1.03';
 
 =head1 NAME
 
@@ -32,7 +30,7 @@ This class is used to identify all image nodes in a page content tree.
 
 =over
 
-=item $self->new()
+=item new
 
 Creates a new renderer.
 
@@ -46,7 +44,7 @@ sub new
    }, $pkg;
 }
 
-=item $self->clone()
+=item clone
 
 Duplicates an instance.  The new instance deliberately shares its
 C<images> property with the original instance.
@@ -63,7 +61,7 @@ sub clone
    return $self;
 }
 
-=item $self->Do(DATA...)
+=item Do DATA...
 
 Record an indirect image node.
 
@@ -78,10 +76,9 @@ sub Do
       type => 'Do',
       value => $value,
    };
-   return;
 }
 
-=item $self->BI(DATA...)
+=item BI DATA...
 
 Record an inline image node.
 
@@ -96,7 +93,6 @@ sub BI
       type => 'BI',
       value => $value,
    };
-   return;
 }
 
 1;
@@ -107,5 +103,3 @@ __END__
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
-
-=cut
