@@ -1,15 +1,11 @@
 #!/usr/bin/perl -w
 
-package main;
-
 use warnings;
 use strict;
 use CAM::PDF;
 use Getopt::Long;
 use Pod::Usage;
 
-our $VERSION = '1.04_01';
-
 my %opts = (
             verbose    => 0,
             order      => 0,
@@ -70,15 +66,13 @@ else
 
 __END__
 
-=for stopwords changepdfstring.pl
-
 =head1 NAME
 
 changepdfstring.pl - Search and replace in PDF metadata
 
 =head1 SYNOPSIS
 
- changepdfstring.pl [options] infile.pdf search-str replace-str [outfile.pdf]
+changepdfstring.pl [options] infile.pdf search-str replace-str [outfile.pdf]
 
  Options:
    -o --order          preserve the internal PDF ordering for output
@@ -88,12 +82,12 @@ changepdfstring.pl - Search and replace in PDF metadata
 
 =head1 DESCRIPTION
 
-Searches through a PDF file's metadata for instances of C<search-str> and
-inserts C<replace-str>.  Note that this does not change the actual PDF
+Searches through a PDF file's metadata for instances of search-str and
+inserts replace-str.  Note that this does not change the actual PDF
 page layout, but only interactive features, like forms and annotation.
-To change page layout strings, use instead F<changepagestring.pl>.
+To change page layout strings, use instead changepagestring.pl.
 
-The C<search-str> can be a literal string, or it can be a Perl regular
+The search-str can be a literal string, or it can be a Perl regular
 expression by wrapping it in C<regex(...)>.  For example:
 
   changepdfstring.pl in.pdf 'regex(CAM-PDF-(\d.\d+))' 'version=$1' out.pdf
@@ -102,10 +96,9 @@ expression by wrapping it in C<regex(...)>.  For example:
 
 CAM::PDF
 
-F<changepagestring.pl>
+changepagestring.pl
 
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
 
-=cut
