@@ -1,15 +1,11 @@
 #!/usr/bin/perl -w
 
-package main;
-
 use warnings;
 use strict;
 use CAM::PDF;
 use Getopt::Long;
 use Pod::Usage;
 
-our $VERSION = '1.04_01';
-
 my %opts = (
             verbose    => 0,
             order      => 0,
@@ -61,15 +57,13 @@ $doc->cleanoutput($outfile);
 
 __END__
 
-=for stopwords deletepdfpage.pl
-
 =head1 NAME
 
 deletepdfpage.pl - Remove one or more pages from a PDF
 
 =head1 SYNOPSIS
 
- deletepdfpage.pl [options] infile.pdf <pagenums> [outfile.pdf]
+deletepdfpage.pl [options] infile.pdf <pagenums> [outfile.pdf]
 
  Options:
    -o --order          preserve the internal PDF ordering for output
@@ -91,10 +85,8 @@ Illustrator emits.
 
 CAM::PDF
 
-C<appendpdf.pl>
+appendpdf.pl
 
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
-
-=cut
