@@ -1,15 +1,11 @@
 #!/usr/bin/perl -w
 
-package main;
-
 use warnings;
 use strict;
 use CAM::PDF;
 use Getopt::Long;
 use Pod::Usage;
 
-our $VERSION = '1.04_01';
-
 my %opts = (
             template   => 'crunchjpg_tmpl.pdf',
 
@@ -42,7 +38,7 @@ foreach my $flag (qw( skip ))
 {
    foreach my $val (@{$opts{$flag.'val'}})
    {
-      foreach my $key (split /\D+/xms, $val)
+      foreach my $key (split /\D+/, $val)
       {
          $opts{$flag}->{$key} = 1;
       }
@@ -71,10 +67,10 @@ my %doneobjs = ();
 for my $p (1..$pages)
 {
    my $c = $doc->getPageContent($p);
-   my @parts = split /(\/[\w]+\s*Do)\b/xms, $c;
+   my @parts = split /(\/[\w]+\s*Do)\b/s, $c;
    foreach my $part (@parts)
    {
-      if ($part =~ m/\A(\/[\w]+)\s*Do\z/xms)
+      if ($part =~ /^(\/[\w]+)\s*Do$/s)
       {
          my $ref = $1;
          my $xobj = $doc->dereference($ref, $p);
@@ -159,8 +155,8 @@ for my $p (1..$pages)
             $media_array->[2]->{value} = $w;
             $media_array->[3]->{value} = $h;
             my $page = $rawpage;
-            $page =~ s/xxx/$w/igxms;
-            $page =~ s/yyy/$h/igxms;
+            $page =~ s/xxx/$w/ig;
+            $page =~ s/yyy/$h/ig;
             $tmpl->setPageContent(1, $page);
             $tmpl->replaceObject(9, $doc, $objnum, 1);
 
@@ -192,21 +188,18 @@ sub _inform
    {
       print STDERR $str, "\n";
    }
-   return;
 }
 
 
 __END__
 
-=for stopwords extractjpgs.pl ImageMagick JPG
-
 =head1 NAME
 
 extractjpgs.pl - Save copies of all PDF JPG images to a directory
 
 =head1 SYNOPSIS
 
- extractjpgs.pl [options] infile.pdf outdirectory
+extractjpgs.pl [options] infile.pdf outdirectory
 
  Options:
    -S --skip=imnum     don't output the specified images (can be used mutliple times)
@@ -215,30 +208,28 @@ extractjpgs.pl - Save copies of all PDF JPG images to a directory
    -V --version        print CAM::PDF version
 
 C<imnum> is a comma-separated list of integers indicating the images
-in order that they appear in the PDF.  Use F<listimages.pl> to retrieve
+in order that they appear in the PDF.  Use listimages.pl to retrieve
 the image numbers.
 
 =head1 DESCRIPTION
 
-Requires the ImageMagick B<convert> program to be available
+Requires the ImageMagick C<convert> program to be available
 
 Searches the PDF for JPG images and saves them as individual files in the
-specified directory.  The files are named C<E<lt>imnumE<gt>.jpg>.
+specified directory.  The files are named <imnum>.jpg.
 
 =head1 SEE ALSO
 
 CAM::PDF
 
-F<crunchjpgs.pl>
+crunchjpgs.pl
 
-F<listimages.pl>
+listimages.pl
 
-F<extractallimages.pl>
+extractallimages.pl
 
-F<uninlinepdfimages.pl>
+uninlinepdfimages.pl
 
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
-
-=cut
