@@ -1,15 +1,11 @@
 #!/usr/bin/perl -w
 
-package main;
-
 use warnings;
 use strict;
 use CAM::PDF;
 use Getopt::Long;
 use Pod::Usage;
 
-our $VERSION = '1.04_01';
-
 my %opts = (
             sort       => 0,
             verbose    => 0,
@@ -157,21 +153,19 @@ for my $p (1 .. $doc->numPages())
 # Only if if $opts{sort} is set
 foreach my $fontname (sort keys %fonts)
 {
-   $fonts{$fontname} =~ s/ ^[ ][ ] //gxms;
+   $fonts{$fontname} =~ s/^  //gm;
    print $fonts{$fontname};
 }
 
 __END__
 
-=for stopwords listfonts.pl
-
 =head1 NAME
 
 listfonts.pl - Print details of the fonts used in the PDF
 
 =head1 SYNOPSIS
 
- listfonts.pl [options] infile.pdf
+listfonts.pl [options] infile.pdf
 
  Options:
    -s --sort           sort the fonts by name, not by page
@@ -190,5 +184,3 @@ CAM::PDF
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
-
-=cut
